Struct HierarchyPropagatePlugin
pub struct HierarchyPropagatePlugin<C, F = (), R = ChildOf>{ /* private fields */ }Expand description
Plugin to automatically propagate a component value to all direct and transient relationship
targets (e.g. bevy_ecs::hierarchy::Children) of entities with a Propagate component.
The plugin Will maintain the target component over hierarchy changes, adding or removing
C when a relationship R (e.g. ChildOf) is added to or removed from a
relationship tree with a Propagate<C> source, or if the Propagate<C> component
is added, changed or removed.
Optionally you can include a query filter F to restrict the entities that are updated.
Note that the filter is not rechecked dynamically: changes to the filter state will not be
picked up until the Propagate component is touched, or the hierarchy is changed.
All members of the tree between source and target must match the filter for propagation
to reach a given target.
Individual entities can be skipped or terminate the propagation with the PropagateOver
and PropagateStop components.
The schedule can be configured via HierarchyPropagatePlugin::new.
You should be sure to schedule your logic relative to this set: making changes
that modify component values before this logic, and reading the propagated
values after it.
Implementations
impl<C, F, R> HierarchyPropagatePlugin<C, F, R>
impl<C, F, R> HierarchyPropagatePlugin<C, F, R>
pub fn new(schedule: impl ScheduleLabel) -> HierarchyPropagatePlugin<C, F, R>
pub fn new(schedule: impl ScheduleLabel) -> HierarchyPropagatePlugin<C, F, R>
Construct the plugin. The propagation systems will be placed in the specified schedule.