MainScheduleOrder

Struct MainScheduleOrder 

pub struct MainScheduleOrder {
    pub labels: Vec<Interned<dyn ScheduleLabel>>,
    pub startup_labels: Vec<Interned<dyn ScheduleLabel>>,
}
Defines the schedules to be run for the Main schedule, including their order.

Fields

labels: Vec<Interned<dyn ScheduleLabel>>

The labels to run for the main phase of the Main schedule (in the order they will be run).

startup_labels: Vec<Interned<dyn ScheduleLabel>>

The labels to run for the startup phase of the Main schedule (in the order they will be run).

Implementations



impl MainScheduleOrder

pub fn insert_after( &mut self, after: impl ScheduleLabel, schedule: impl ScheduleLabel, )

Adds the given schedule after the after schedule in the main list of schedules.

pub fn insert_before( &mut self, before: impl ScheduleLabel, schedule: impl ScheduleLabel, )

Adds the given schedule before the before schedule in the main list of schedules.

pub fn insert_startup_after( &mut self, after: impl ScheduleLabel, schedule: impl ScheduleLabel, )

Adds the given schedule after the after schedule in the list of startup schedules.

pub fn insert_startup_before( &mut self, before: impl ScheduleLabel, schedule: impl ScheduleLabel, )

Adds the given schedule before the before schedule in the list of startup schedules.