Struct PluginGroupBuilder
pub struct PluginGroupBuilder { /* private fields */ }Expand description
Facilitates the creation and configuration of a PluginGroup.
Provides a build ordering to ensure that Plugins which produce/require a Resource
are built before/after dependent/depending Plugins. Plugins inside the group
can be disabled, enabled or reordered.
Implementations
impl PluginGroupBuilder
impl PluginGroupBuilder
pub fn start<PG>() -> PluginGroupBuilderwhere
PG: PluginGroup,
pub fn start<PG>() -> PluginGroupBuilderwhere
PG: PluginGroup,
Start a new builder for the PluginGroup.
pub fn contains<T>(&self) -> boolwhere
T: Plugin,
pub fn contains<T>(&self) -> boolwhere
T: Plugin,
Checks if the PluginGroupBuilder contains the given Plugin.
pub fn enabled<T>(&self) -> boolwhere
T: Plugin,
pub fn enabled<T>(&self) -> boolwhere
T: Plugin,
Returns true if the PluginGroupBuilder contains the given Plugin and it’s enabled.
pub fn set<T>(self, plugin: T) -> PluginGroupBuilderwhere
T: Plugin,
pub fn set<T>(self, plugin: T) -> PluginGroupBuilderwhere
T: Plugin,
pub fn try_set<T>(
self,
plugin: T,
) -> Result<PluginGroupBuilder, (PluginGroupBuilder, T)>where
T: Plugin,
pub fn try_set<T>(
self,
plugin: T,
) -> Result<PluginGroupBuilder, (PluginGroupBuilder, T)>where
T: Plugin,
pub fn add<T>(self, plugin: T) -> PluginGroupBuilderwhere
T: Plugin,
pub fn add<T>(self, plugin: T) -> PluginGroupBuilderwhere
T: Plugin,
Adds the plugin Plugin at the end of this PluginGroupBuilder. If the plugin was
already in the group, it is removed from its previous place.
pub fn try_add<T>(
self,
plugin: T,
) -> Result<PluginGroupBuilder, (PluginGroupBuilder, T)>where
T: Plugin,
pub fn try_add<T>(
self,
plugin: T,
) -> Result<PluginGroupBuilder, (PluginGroupBuilder, T)>where
T: Plugin,
Attempts to add the plugin Plugin at the end of this PluginGroupBuilder.
If the plugin was already in the group the addition fails.
pub fn add_group(self, group: impl PluginGroup) -> PluginGroupBuilder
pub fn add_group(self, group: impl PluginGroup) -> PluginGroupBuilder
Adds a PluginGroup at the end of this PluginGroupBuilder. If the plugin was
already in the group, it is removed from its previous place.
pub fn add_before<Target>(self, plugin: impl Plugin) -> PluginGroupBuilderwhere
Target: Plugin,
pub fn add_before<Target>(self, plugin: impl Plugin) -> PluginGroupBuilderwhere
Target: Plugin,
Adds a Plugin in this PluginGroupBuilder before the plugin of type Target.
If the plugin was already the group, it is removed from its previous place.
Panics
Panics if Target is not already in this PluginGroupBuilder.
pub fn try_add_before<Target, Insert>(
self,
plugin: Insert,
) -> Result<PluginGroupBuilder, (PluginGroupBuilder, Insert)>
pub fn try_add_before<Target, Insert>( self, plugin: Insert, ) -> Result<PluginGroupBuilder, (PluginGroupBuilder, Insert)>
Adds a Plugin in this PluginGroupBuilder before the plugin of type Target.
If the plugin was already in the group the add fails. If there isn’t a plugin
of type Target in the group the plugin we’re trying to insert is returned.
pub fn try_add_before_overwrite<Target, Insert>(
self,
plugin: Insert,
) -> Result<PluginGroupBuilder, (PluginGroupBuilder, Insert)>
pub fn try_add_before_overwrite<Target, Insert>( self, plugin: Insert, ) -> Result<PluginGroupBuilder, (PluginGroupBuilder, Insert)>
Adds a Plugin in this PluginGroupBuilder before the plugin of type Target.
If the plugin was already in the group, it is removed from its previous places.
If there isn’t a plugin of type Target in the group the plugin we’re trying to insert
is returned.
pub fn add_after<Target>(self, plugin: impl Plugin) -> PluginGroupBuilderwhere
Target: Plugin,
pub fn add_after<Target>(self, plugin: impl Plugin) -> PluginGroupBuilderwhere
Target: Plugin,
Adds a Plugin in this PluginGroupBuilder after the plugin of type Target.
If the plugin was already the group, it is removed from its previous place.
Panics
Panics if Target is not already in this PluginGroupBuilder.
pub fn try_add_after<Target, Insert>(
self,
plugin: Insert,
) -> Result<PluginGroupBuilder, (PluginGroupBuilder, Insert)>
pub fn try_add_after<Target, Insert>( self, plugin: Insert, ) -> Result<PluginGroupBuilder, (PluginGroupBuilder, Insert)>
Adds a Plugin in this PluginGroupBuilder after the plugin of type Target.
If the plugin was already in the group the add fails. If there isn’t a plugin
of type Target in the group the plugin we’re trying to insert is returned.
pub fn try_add_after_overwrite<Target, Insert>(
self,
plugin: Insert,
) -> Result<PluginGroupBuilder, (PluginGroupBuilder, Insert)>
pub fn try_add_after_overwrite<Target, Insert>( self, plugin: Insert, ) -> Result<PluginGroupBuilder, (PluginGroupBuilder, Insert)>
Adds a Plugin in this PluginGroupBuilder after the plugin of type Target.
If the plugin was already in the group, it is removed from its previous places.
If there isn’t a plugin of type Target in the group the plugin we’re trying to insert
is returned.
pub fn enable<T>(self) -> PluginGroupBuilderwhere
T: Plugin,
pub fn enable<T>(self) -> PluginGroupBuilderwhere
T: Plugin,
Enables a Plugin.
Plugins within a PluginGroup are enabled by default. This function is used to
opt back in to a Plugin after disabling it. If there are no plugins
of type T in this group, it will panic.
pub fn disable<T>(self) -> PluginGroupBuilderwhere
T: Plugin,
pub fn disable<T>(self) -> PluginGroupBuilderwhere
T: Plugin,
Disables a Plugin, preventing it from being added to the App with the rest of the
PluginGroup. The disabled Plugin keeps its place in the PluginGroup, so it can
still be used for ordering with add_before or
add_after, or it can be re-enabled. If there are no
plugins of type T in this group, it will panic.