PreUpdate

Struct PreUpdate 

pub struct PreUpdate;
The schedule that contains logic that must run before Update. For example, a system that reads raw keyboard input OS events into a Messages resource. This enables systems in Update to consume the messages from the Messages resource without actually knowing about (or taking a direct scheduler dependency on) the “os-level keyboard event system”.

PreUpdate exists to do “engine/plugin preparation work” that ensures the APIs consumed in Update are “ready”. PreUpdate abstracts out “pre work implementation details”.

See the Main schedule for some details about how schedules are run.