Struct SubApps
pub struct SubApps {
pub main: SubApp,
pub sub_apps: HashMap<Interned<dyn AppLabel>, SubApp>,
}Expand description
The collection of sub-apps that belong to an App.
Fields
main: SubAppThe primary sub-app that contains the “main” world.
sub_apps: HashMap<Interned<dyn AppLabel>, SubApp>Other, labeled sub-apps.
Implementations
impl SubApps
impl SubApps
pub fn update(&mut self)
pub fn update(&mut self)
pub fn iter(&self) -> impl Iterator<Item = &SubApp>
pub fn iter(&self) -> impl Iterator<Item = &SubApp>
Returns an iterator over the sub-apps (starting with the main one).
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut SubApp>
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut SubApp>
Returns a mutable iterator over the sub-apps (starting with the main one).
pub fn update_subapp_by_label(&mut self, label: impl AppLabel)
pub fn update_subapp_by_label(&mut self, label: impl AppLabel)
Extract data from the main world into the SubApp with the given label and perform an update if it exists.