Struct TerminalCtrlCHandlerPlugin
pub struct TerminalCtrlCHandlerPlugin;Expand description
Gracefully handles Ctrl+C by emitting a AppExit event. This plugin is part of the DefaultPlugins.
fn main() {
App::new()
.add_plugins(MinimalPlugins)
.add_plugins(TerminalCtrlCHandlerPlugin)
.run();
}If you want to setup your own Ctrl+C handler, you should call the
TerminalCtrlCHandlerPlugin::gracefully_exit function in your handler if you want bevy to gracefully exit.
fn main() {
// Your own `Ctrl+C` handler
ctrlc::set_handler(move || {
// Other clean up code ...
TerminalCtrlCHandlerPlugin::gracefully_exit();
});
App::new()
.add_plugins(DefaultPlugins)
.run();
}Implementations
impl TerminalCtrlCHandlerPlugin
impl TerminalCtrlCHandlerPlugin
pub fn gracefully_exit()
pub fn gracefully_exit()
When called the first time, it sends the AppExit event to all apps using
this plugin to make them gracefully exit.
If called more than once, it exits immediately.
pub fn exit_on_flag(app_exit_writer: MessageWriter<'_, AppExit>)
pub fn exit_on_flag(app_exit_writer: MessageWriter<'_, AppExit>)
Sends a AppExit event when the user presses Ctrl+C on the terminal.