Struct PluginGroupBuilder
pub struct PluginGroupBuilder { /* private fields */ }Expand description
Facilitates the creation and configuration of a PluginGroup.
Provides a build ordering to ensure that Plugins which produce/require a Resource
are built before/after dependent/depending Plugins. Plugins inside the group
can be disabled, enabled or reordered.
Implementations
impl PluginGroupBuilder
impl PluginGroupBuilder
pub fn start<PG>() -> PluginGroupBuilderwhere
PG: PluginGroup,
pub fn start<PG>() -> PluginGroupBuilderwhere
PG: PluginGroup,
Start a new builder for the PluginGroup.
pub fn set<T>(self, plugin: T) -> PluginGroupBuilderwhere
T: Plugin,
pub fn set<T>(self, plugin: T) -> PluginGroupBuilderwhere
T: Plugin,
pub fn add<T>(self, plugin: T) -> PluginGroupBuilderwhere
T: Plugin,
pub fn add<T>(self, plugin: T) -> PluginGroupBuilderwhere
T: Plugin,
Adds the plugin Plugin at the end of this PluginGroupBuilder. If the plugin was
already in the group, it is removed from its previous place.
pub fn add_group(self, group: impl PluginGroup) -> PluginGroupBuilder
pub fn add_group(self, group: impl PluginGroup) -> PluginGroupBuilder
Adds a PluginGroup at the end of this PluginGroupBuilder. If the plugin was
already in the group, it is removed from its previous place.
pub fn add_before<Target, T>(self, plugin: T) -> PluginGroupBuilder
pub fn add_before<Target, T>(self, plugin: T) -> PluginGroupBuilder
Adds a Plugin in this PluginGroupBuilder before the plugin of type Target.
If the plugin was already the group, it is removed from its previous place. There must
be a plugin of type Target in the group or it will panic.
pub fn add_after<Target, T>(self, plugin: T) -> PluginGroupBuilder
pub fn add_after<Target, T>(self, plugin: T) -> PluginGroupBuilder
Adds a Plugin in this PluginGroupBuilder after the plugin of type Target.
If the plugin was already the group, it is removed from its previous place. There must
be a plugin of type Target in the group or it will panic.
pub fn enable<T>(self) -> PluginGroupBuilderwhere
T: Plugin,
pub fn enable<T>(self) -> PluginGroupBuilderwhere
T: Plugin,
Enables a Plugin.
Plugins within a PluginGroup are enabled by default. This function is used to
opt back in to a Plugin after disabling it. If there are no plugins
of type T in this group, it will panic.
pub fn disable<T>(self) -> PluginGroupBuilderwhere
T: Plugin,
pub fn disable<T>(self) -> PluginGroupBuilderwhere
T: Plugin,
Disables a Plugin, preventing it from being added to the App with the rest of the
PluginGroup. The disabled Plugin keeps its place in the PluginGroup, so it can
still be used for ordering with add_before or
add_after, or it can be re-enabled. If there are no
plugins of type T in this group, it will panic.